@@ -20,7 +20,7 @@ public:
     };
 
     DirectoryChooserWidget(Flags flags);
-    ~DirectoryChooserWidget();
+    ~DirectoryChooserWidget() override;
 
     PlasmaVault::Vault::Payload fields() const override;
     void init(const PlasmaVault::Vault::Payload &payload) override;
